### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [v0.3.8](https://github.com/keyko-io/defi-crawler-py/compare/v0.3.7...v0.3.8)

> 10 December 2021

- liquidity [`#66`](https://github.com/keyko-io/defi-crawler-py/pull/66)
- merge main [`a3f44ac`](https://github.com/keyko-io/defi-crawler-py/commit/a3f44acbc6fad4cb4cc46ecc339077fc4f307db3)

#### [v0.3.7](https://github.com/keyko-io/defi-crawler-py/compare/v0.3.6...v0.3.7)

> 4 December 2021

- pool timestamp [`#65`](https://github.com/keyko-io/defi-crawler-py/pull/65)
- Adding v0.3.6 Changelog updates [`3933394`](https://github.com/keyko-io/defi-crawler-py/commit/3933394375bdade26f0e3fdd997e9768d1659842)
- version [`3bc1566`](https://github.com/keyko-io/defi-crawler-py/commit/3bc1566e371939f181990b64b28579c5aafb6512)
- version [`d6bee6d`](https://github.com/keyko-io/defi-crawler-py/commit/d6bee6d7f42721df942429c66ffd26c118663ab2)

#### [v0.3.6](https://github.com/keyko-io/defi-crawler-py/compare/v0.3.5...v0.3.6)

> 31 October 2021

#### [v0.3.5](https://github.com/keyko-io/defi-crawler-py/compare/v0.3.4...v0.3.5)

> 31 October 2021

- Adding v0.3.4 Changelog updates [`8fbb992`](https://github.com/keyko-io/defi-crawler-py/commit/8fbb99297358fdd33e13cfce97cd8bd993fc9197)
- version [`ed05023`](https://github.com/keyko-io/defi-crawler-py/commit/ed0502391d9d235ed1d7bd95a8f44ce3d89dbaba)
- version [`7794fb8`](https://github.com/keyko-io/defi-crawler-py/commit/7794fb81559a58c953a24a5a3d9fbb0cff11b46e)

#### [v0.3.4](https://github.com/keyko-io/defi-crawler-py/compare/v0.3.3...v0.3.4)

> 31 October 2021

- amount usd swaps [`#63`](https://github.com/keyko-io/defi-crawler-py/pull/63)
- Adding v0.3.3 Changelog updates [`b8b4098`](https://github.com/keyko-io/defi-crawler-py/commit/b8b409827506ddac179a1a980409f36599bb22bb)

#### [v0.3.3](https://github.com/keyko-io/defi-crawler-py/compare/v0.3.2...v0.3.3)

> 20 October 2021

- add cream chains [`#61`](https://github.com/keyko-io/defi-crawler-py/pull/61)
- dex protocols [`#60`](https://github.com/keyko-io/defi-crawler-py/pull/60)
- add sushi celo [`#59`](https://github.com/keyko-io/defi-crawler-py/pull/59)
- add aave avalanche [`#58`](https://github.com/keyko-io/defi-crawler-py/pull/58)
- add dodoex  [`#57`](https://github.com/keyko-io/defi-crawler-py/pull/57)
- add pangolin and traderjoe support [`#53`](https://github.com/keyko-io/defi-crawler-py/pull/53)
- retry on calls [`#52`](https://github.com/keyko-io/defi-crawler-py/pull/52)
- add dodoex swaps [`fbd5daa`](https://github.com/keyko-io/defi-crawler-py/commit/fbd5daa040ac3477dcd4d82ec5c8d1348377fbcf)
- fix tests [`871264b`](https://github.com/keyko-io/defi-crawler-py/commit/871264bacf7c47646f57abdc0b33a664546e4890)
- Adding v0.3.2 Changelog updates [`16e8b8a`](https://github.com/keyko-io/defi-crawler-py/commit/16e8b8aa07b5ecc6d24df3e994a8f6cb05f6459a)

#### [v0.3.2](https://github.com/keyko-io/defi-crawler-py/compare/v0.3.1...v0.3.2)

> 4 October 2021

- add support mint & burn liquidity providers [`#50`](https://github.com/keyko-io/defi-crawler-py/pull/50)
- Adding v0.3.1 Changelog updates [`63cab75`](https://github.com/keyko-io/defi-crawler-py/commit/63cab757ebef1156df43a375de003ce10429aebf)
- version [`a4ed44f`](https://github.com/keyko-io/defi-crawler-py/commit/a4ed44f98f178c52e22ff250d0c5fff47f702bc2)

#### [v0.3.1](https://github.com/keyko-io/defi-crawler-py/compare/v0.3.0...v0.3.1)

> 1 October 2021

- Feat/lending [`#48`](https://github.com/keyko-io/defi-crawler-py/pull/48)
- add pool on swap entity [`#49`](https://github.com/keyko-io/defi-crawler-py/pull/49)
- add kashi lending support eth & polygon [`bd97b6c`](https://github.com/keyko-io/defi-crawler-py/commit/bd97b6cb41b0680a722ce509896cc082a86f76b9)
- add support kashi borrows [`11f0481`](https://github.com/keyko-io/defi-crawler-py/commit/11f0481b3a60564af4f72dbd234acf115ca484be)
- Adding v0.3.0 Changelog updates [`95818e2`](https://github.com/keyko-io/defi-crawler-py/commit/95818e28d100c35ef1dfcd1bfa4ac855d576b36d)

#### [v0.3.0](https://github.com/keyko-io/defi-crawler-py/compare/v0.2.9...v0.3.0)

> 27 September 2021

- Feat/lending [`#47`](https://github.com/keyko-io/defi-crawler-py/pull/47)
- add user filter [`7b7716c`](https://github.com/keyko-io/defi-crawler-py/commit/7b7716c63d04ee6e48c7e8b780ef5bce77e6f09f)
- cream support polygon & arbitrum [`4ed6397`](https://github.com/keyko-io/defi-crawler-py/commit/4ed63978e23f6058695ab5cd29d721274b4b4a4c)
- Adding v0.2.9 Changelog updates [`e3b8ddf`](https://github.com/keyko-io/defi-crawler-py/commit/e3b8ddfd5a17da6c1883bf000f0cce71e59dad48)

#### [v0.2.9](https://github.com/keyko-io/defi-crawler-py/compare/v0.2.8...v0.2.9)

> 1 September 2021

- add dex protocols [`#46`](https://github.com/keyko-io/defi-crawler-py/pull/46)
- add uniswap v3 [`083ed10`](https://github.com/keyko-io/defi-crawler-py/commit/083ed101ab43e966a3525a02940b5a70974f5ab1)
- add panckeswap v2 [`03d2257`](https://github.com/keyko-io/defi-crawler-py/commit/03d2257b2e8968e866886b288fe4ebf3c0b57f75)
- add balancer v2 [`b04f88e`](https://github.com/keyko-io/defi-crawler-py/commit/b04f88ecc2dee658a8efd735fb4ff979eaeded32)

#### [v0.2.8](https://github.com/keyko-io/defi-crawler-py/compare/v0.2.7...v0.2.8)

> 31 August 2021

- Feat/lending entities [`#45`](https://github.com/keyko-io/defi-crawler-py/pull/45)
- add redeem and flashloans [`1d93678`](https://github.com/keyko-io/defi-crawler-py/commit/1d936789ccbf49137b029c7d9d0bded2d237ca3f)
- aave v2 flashloans [`6fda3cd`](https://github.com/keyko-io/defi-crawler-py/commit/6fda3cd88b7bfa341bd23ffca46975f1b371e4b2)
- Adding v0.2.7 Changelog updates [`5083d39`](https://github.com/keyko-io/defi-crawler-py/commit/5083d39edca5ea825d0bca6125c9bf80db4854ae)

#### [v0.2.7](https://github.com/keyko-io/defi-crawler-py/compare/v0.2.6...v0.2.7)

> 12 July 2021

- fix timestamps [`#43`](https://github.com/keyko-io/defi-crawler-py/pull/43)
- updating timestamp for date queries [`#42`](https://github.com/keyko-io/defi-crawler-py/pull/42)
- Adding v.0.2.6 Changelog updates [`23e889d`](https://github.com/keyko-io/defi-crawler-py/commit/23e889de59e876178f3e220d9af199f5d1187d18)

#### [v0.2.6](https://github.com/keyko-io/defi-crawler-py/compare/v0.2.5...v0.2.6)

> 1 July 2021

- fix sushi pool [`#40`](https://github.com/keyko-io/defi-crawler-py/pull/40)
- Feat/block info [`#39`](https://github.com/keyko-io/defi-crawler-py/pull/39)
- Adding v0.2.5 Changelog updates [`8439864`](https://github.com/keyko-io/defi-crawler-py/commit/8439864318b7ee8285f698a11a73fd48780e2fdc)

#### [v0.2.5](https://github.com/keyko-io/defi-crawler-py/compare/v0.2.4...v0.2.5)

> 23 June 2021

- blocks info [`f1ac329`](https://github.com/keyko-io/defi-crawler-py/commit/f1ac329a0f28a89fbd06de6524e6dcb465b73eb6)
- version [`2eb7c18`](https://github.com/keyko-io/defi-crawler-py/commit/2eb7c185a6a2a630334c4ce6669f2cbfd62f5065)

#### [v0.2.4](https://github.com/keyko-io/defi-crawler-py/compare/v0.2.3...v0.2.4)

> 16 June 2021

- Adding v.0.2.3 Changelog updates [`0e9969c`](https://github.com/keyko-io/defi-crawler-py/commit/0e9969cbaf82e5a84a6e5f031ccd9ea5baf3f13c)
- version [`18a9aa1`](https://github.com/keyko-io/defi-crawler-py/commit/18a9aa1e0f1f1adf760c186aca69733dddbc64b4)

#### [v0.2.3](https://github.com/keyko-io/defi-crawler-py/compare/v0.2.2...v0.2.3)

> 16 June 2021

- oracle fix [`#38`](https://github.com/keyko-io/defi-crawler-py/pull/38)

#### [v0.2.2](https://github.com/keyko-io/defi-crawler-py/compare/v0.2.1...v0.2.2)

> 16 June 2021

- version [`aa03221`](https://github.com/keyko-io/defi-crawler-py/commit/aa0322146531e185d61795afa379ed11a8c6e98d)

#### [v0.2.1](https://github.com/keyko-io/defi-crawler-py/compare/v0.2.0...v0.2.1)

> 16 June 2021

- Adding v.0.2.0 Changelog updates [`3c05584`](https://github.com/keyko-io/defi-crawler-py/commit/3c05584c77c98dbc1f50fbf02f7b03584311f9e9)

#### [v0.2.0](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.9...v0.2.0)

> 16 June 2021

- Feat/rates lending [`#37`](https://github.com/keyko-io/defi-crawler-py/pull/37)
- compound rates [`80418c5`](https://github.com/keyko-io/defi-crawler-py/commit/80418c56920ff8a8ab2f8d5a6e36b4809df6c1d8)
- cream rates [`9e88f77`](https://github.com/keyko-io/defi-crawler-py/commit/9e88f771bca054ed09aacad3c6e845d294c399e6)
- aave rates [`94a828b`](https://github.com/keyko-io/defi-crawler-py/commit/94a828b91abba1d9832bc02b4b225259716e96f7)

#### [v0.1.9](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.8...v0.1.9)

> 18 May 2021

- package data [`696cc73`](https://github.com/keyko-io/defi-crawler-py/commit/696cc73822e970d0d464391cd58a82d7a61fc722)

#### [v0.1.8](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.7...v0.1.8)

> 18 May 2021

- Adding v0.17 Changelog updates [`bcec1f7`](https://github.com/keyko-io/defi-crawler-py/commit/bcec1f71f606dc548d3e226b744fd6b23d840eb9)
- add json manifest [`a25fcc9`](https://github.com/keyko-io/defi-crawler-py/commit/a25fcc975c3045ec72edbc4b1076ffaa983bec92)

#### [v0.1.7](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.6...v0.1.7)

> 18 May 2021

- Adding v0.1.6 Changelog updates [`041787e`](https://github.com/keyko-io/defi-crawler-py/commit/041787e4794570029baa28d5df0406b6f90bcb35)
- version [`85e6112`](https://github.com/keyko-io/defi-crawler-py/commit/85e61128769d7b9526d44b250738ecb9503180ea)
- version [`68a30a1`](https://github.com/keyko-io/defi-crawler-py/commit/68a30a1de3050689976daa5a0e9a8e28b4d9497d)

#### [v0.1.6](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.5...v0.1.6)

> 18 May 2021

- Adding v0.1.5 Changelog updates [`266362f`](https://github.com/keyko-io/defi-crawler-py/commit/266362f769a7bb64b47d44e939ba97feb434b42a)
- manifest [`9b74929`](https://github.com/keyko-io/defi-crawler-py/commit/9b749296d3f94fcea86e1d4199e3aa9f6d54b00b)

#### [v0.1.5](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.4...v0.1.5)

> 18 May 2021

- Adding v0.1.4 Changelog updates [`4fd4081`](https://github.com/keyko-io/defi-crawler-py/commit/4fd40811237eca74fe50572a5051a26ba142bcc8)
- manifest [`8cb2942`](https://github.com/keyko-io/defi-crawler-py/commit/8cb29425fc22fafa44a6f7e6ebceddba5e5e90af)

#### [v0.1.4](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.2...v0.1.4)

> 18 May 2021

#### [v0.1.2](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.1...v0.1.2)

> 18 May 2021

- Adding v0.1.1 Changelog updates [`fe97ab2`](https://github.com/keyko-io/defi-crawler-py/commit/fe97ab232822014d3840124715452d2829096683)
- Update setup.py [`d1fa65d`](https://github.com/keyko-io/defi-crawler-py/commit/d1fa65d5606e634bd8ebf431955b39a3ff5451b1)

#### [v0.1.1](https://github.com/keyko-io/defi-crawler-py/compare/v0.1.0...v0.1.1)

> 18 May 2021

- Adding v0.1.0  Changelog updates [`360b7f0`](https://github.com/keyko-io/defi-crawler-py/commit/360b7f0195eab717a2d7854d7ab49b025e1bf844)

#### v0.1.0

> 18 May 2021

- setup config and examples [`#35`](https://github.com/keyko-io/defi-crawler-py/pull/35)
- dexes [`#34`](https://github.com/keyko-io/defi-crawler-py/pull/34)
- pool filter [`#33`](https://github.com/keyko-io/defi-crawler-py/pull/33)
- feat: supported entities [`#32`](https://github.com/keyko-io/defi-crawler-py/pull/32)
- update docs after refactor [`#31`](https://github.com/keyko-io/defi-crawler-py/pull/31)
- refactor split protocol types [`#30`](https://github.com/keyko-io/defi-crawler-py/pull/30)
- Feat/exchange prices [`#29`](https://github.com/keyko-io/defi-crawler-py/pull/29)
- Docs [`#28`](https://github.com/keyko-io/defi-crawler-py/pull/28)
- comments [`#25`](https://github.com/keyko-io/defi-crawler-py/pull/25)
- Integration tests [`#24`](https://github.com/keyko-io/defi-crawler-py/pull/24)
- Unit testing [`#23`](https://github.com/keyko-io/defi-crawler-py/pull/23)
- refactor [`#22`](https://github.com/keyko-io/defi-crawler-py/pull/22)
- oracles [`#21`](https://github.com/keyko-io/defi-crawler-py/pull/21)
- feat: lending protocols [`#20`](https://github.com/keyko-io/defi-crawler-py/pull/20)
- refactor: extra query fields [`#19`](https://github.com/keyko-io/defi-crawler-py/pull/19)
- units functions [`#17`](https://github.com/keyko-io/defi-crawler-py/pull/17)
- several blockchains [`#16`](https://github.com/keyko-io/defi-crawler-py/pull/16)
- users data [`#15`](https://github.com/keyko-io/defi-crawler-py/pull/15)
- dynamic mappings, transforms &  json configs [`#14`](https://github.com/keyko-io/defi-crawler-py/pull/14)
- Feature/dynamic mappings [`#12`](https://github.com/keyko-io/defi-crawler-py/pull/12)
- amm docs [`#10`](https://github.com/keyko-io/defi-crawler-py/pull/10)
- prices entities [`#8`](https://github.com/keyko-io/defi-crawler-py/pull/8)
- Feat/lending docs [`#7`](https://github.com/keyko-io/defi-crawler-py/pull/7)
- lending mappers [`d7733a1`](https://github.com/keyko-io/defi-crawler-py/commit/d7733a102e51c3c72c8adc9dc78d17e339fe2b77)
- amm mappers and dinamic querys [`0b6fee6`](https://github.com/keyko-io/defi-crawler-py/commit/0b6fee61f56dbeca08fa01a1ee831b3fccc47fe7)
- integration tests [`9065f3c`](https://github.com/keyko-io/defi-crawler-py/commit/9065f3c621e0108dca94c10a889420fcb2be1de1)
